@@ -110,7 +110,7 @@ typedef struct _NMPlatformIP6Route       NMPlatformIP6Route;
 typedef struct _NMPlatformLink           NMPlatformLink;
 typedef struct _NMPObject                NMPObject;
 
-typedef enum {
+typedef enum _nm_packed {
     NMP_OBJECT_TYPE_UNKNOWN,
     NMP_OBJECT_TYPE_LINK,
 
@@ -148,6 +148,8 @@ typedef enum {
     NMP_OBJECT_TYPE_LNK_VXLAN,
     NMP_OBJECT_TYPE_LNK_WIREGUARD,
 
+    NMP_OBJECT_TYPE_MPTCP_ADDR,
+
     __NMP_OBJECT_TYPE_LAST,
     NMP_OBJECT_TYPE_MAX = __NMP_OBJECT_TYPE_LAST - 1,
 } NMPObjectType;
